"use strict";

const {CoreDefine, CoreClass} = require('@cutos/core');
const {SerialPort} = require("@cutos/drivers");

const {TYPE, CMD} = require('./device-nfc-def.js');
const {DeviceNFCSimulator} = require("./simulator/device-nfc-simulator");
const {opts} = require('./config.json');

class DeviceNFC extends CoreClass.Driver {
    constructor(name) {
        super(name, TYPE);
        if (name === 'mock') {
            this.simulator = new DeviceNFCSimulator()
        }
        this.startBeat();
        this.updateStatusInfo(CoreDefine.HEARTBEAT_STATUS.ALIVE, "alive");
        this.onCommand(({cmd, args}, callback) => {
            switch (cmd) {
                // 必须实现
                case CMD.CONNECT:
                    this.connect(args, callback);
                    break;
            }
        });
    }

    connect(args, callback) {
        let params = {...opts, ...args}
        if (this.port) {
            callback({status: true, msg: params})
        }
        this.port = new SerialPort(params.path, params.baudRate, err => {
            if (err) {
                callback({status: false, msg: err.message})
            } else {
                callback({status: true, msg: params})
            }
        }, this.simulator)
        this.port.on('data', data => this.onSerialData(data))
    }

    onSerialData(data) {
        let code = ''
        data = data.slice(2,)
        for (let d of data) {
            let hex = Number(d).toString(16)
            hex = ('0' + hex).substring(hex.length - 1)
            code += hex
        }
        this.sendData({id: code})
    }
}

module.exports = DeviceNFC;
